@@ -216,13 +216,13 @@ class TuneTheModel():
     _id: str = None
     _status: str = None
     _model_type: str = None
-    _model_user_name: str = None
+    _name: str = None
 
-    def __init__(self, model_name: str, status: str, model_type: str, *args, **kwargs):
-        self._id = model_name
+    def __init__(self, model_id: str, status: str, model_type: str, *args, **kwargs):
+        self._id = model_id
         self._status = status
         self._model_type = model_type
-        self._model_user_name = kwargs["user_name"] if "user_name" in kwargs else None
+        self._name = kwargs["name"] if "name" in kwargs else None
 
     @classmethod
     def from_dict(cls, model: dict) -> 'TuneTheModel':
@@ -234,9 +234,12 @@ class TuneTheModel():
         return cls.from_dict(r)
 
     @classmethod
-    def create_classifier(cls, filename: str = None, train_iters: int = None, num_classes: int = None):
+    def create_classifier(cls, name: str = None, filename: str = None, train_iters: int = None, num_classes: int = None):
         model = {"model_type": "classifier"}
 
+        if name:
+            model["name"] = name
+
         model["model_params"] = {}
         if train_iters:
             model["model_params"]["train_iters"] = train_iters
@@ -246,9 +249,11 @@ class TuneTheModel():
         return cls.create(model, filename)
 
     @classmethod
-    def create_generator(cls, filename: str = None, train_iters: int = None):
+    def create_generator(cls, name: str = None, filename: str = None, train_iters: int = None):
         model = {"model_type": "generator"}
 
+        if name:
+            model["name"] = name
         if train_iters:
             model["model_params"] = {"train_iters": train_iters}
 
@@ -287,7 +292,7 @@ class TuneTheModel():
     def save(self, filename):
         with open(filename, "w") as fl:
             json.dump({
-                "model_name": self._id,
+                "model_id": self._id,
                 "status": self._status,
                 "model_type": self._model_type,
             }, fl)
@@ -392,7 +397,7 @@ class TuneTheModel():
         Raises:
             TuneTheModelException: If anything bad happens.
         """
-        r = TuneTheModelAPI.classify(self._id, input)
+        r = TuneTheModelAPI.classify(self._id, {"input": input})
         return r["answer"]["scores"]
 
     @inited
@@ -418,7 +423,7 @@ class TuneTheModel():
                 "id": self._id,
                 "status": self._status,
                 "model_type": self._model_type,
-                "user_name": self._model_user_name,
+                "user_name": self._name,
             }
         )
 
@@ -428,7 +433,7 @@ class TuneTheModel():
                 "id": self._id,
                 "status": self._status,
                 "model_type": self._model_type,
-                "user_name": self._model_user_name,
+                "user_name": self._name,
             }
         )
 
@@ -440,6 +445,7 @@ def tune_generator(
     validate_X: Union[list, Series, ndarray, None] = None,
     validate_y: Union[list, Series, ndarray, None] = None,
     train_iters: int = None,
+    name: str = None,
     X: Union[list, Series, ndarray, None] = None,
     y: Union[list, Series, ndarray, None] = None,
     test_size=None,
@@ -502,19 +508,20 @@ def tune_generator(
     Raises:
         TuneTheModelException: If anything bad happens.
     """
-    model = TuneTheModel.create_generator(filename, train_iters)
-    model.fit(train_X, train_y, validate_X, validate_y, X, y,
-              test_size, train_size, shuffle, random_state)
+    model = TuneTheModel.create_generator(filename=filename, train_iters=train_iters, name=name)
+    model.fit(train_X=train_X, train_y=train_y, validate_X=validate_X, validate_y=validate_y, X=X, y=y,
+              test_size=test_size, train_size=train_size, shuffle=shuffle, random_state=random_state)
     return model
 
 
 def tune_classifier(
-    filename: str,
+    filename: str = None,
     train_X: Union[list, Series, ndarray, None] = None,
     train_y: Union[list, Series, ndarray, None] = None,
     validate_X: Union[list, Series, ndarray, None] = None,
     validate_y: Union[list, Series, ndarray, None] = None,
     train_iters: int = None,
+    name: str = None,
     num_classes: int = None,
     X: Union[list, Series, ndarray, None] = None,
     y: Union[list, Series, ndarray, None] = None,
@@ -581,9 +588,9 @@ def tune_classifier(
     Raises:
         TuneTheModelException: If anything bad happens.
     """
-    model = TuneTheModel.create_classifier(filename, train_iters, num_classes)
-    model.fit(train_X, train_y, validate_X, validate_y, X, y,
-              test_size, train_size, shuffle, random_state)
+    model = TuneTheModel.create_classifier(filename=filename, train_iters=train_iters, num_classes=num_classes, name=name)
+    model.fit(train_X=train_X, train_y=train_y, validate_X=validate_X, validate_y=validate_y, X=X, y=y,
+              test_size=test_size, train_size=train_size, shuffle=shuffle, random_state=random_state)
     return model
 
 
