@@ -25,7 +25,7 @@ class TuneTheModelAPI():
         "create": ("POST", "{}/v0/models"),
         "models": ("GET", "{}/v0/models"),
         "generate": ("POST", "{}/v0/models/{}/generate"),
-        "classify": ("GET", "{}/v0/models/{}/classify"),
+        "classify": ("POST", "{}/v0/models/{}/classify"),
         "upload": ("POST", "{}/v0/models/{}/upload"),
         "status": ("GET", "{}/v0/models/{}/status"),
         "fit": ("POST", "{}/v0/models/{}/fit"),
@@ -86,8 +86,8 @@ class TuneTheModelAPI():
         return cls._request(*cls._get_V0("models"))
 
     @classmethod
-    def classify(cls, id: str, input: str) -> dict:
-        return cls._request(*cls._get_V0("classify", id), params={"input": input})
+    def classify(cls, id: str, data: dict) -> dict:
+        return cls._request(*cls._get_V0("classify", id), data=json.dumps(data))
 
     @classmethod
     def generate(cls, id: str, data: dict) -> dict:
